.. poplar documentation master file, created by
   sphinx-quickstart on Mon Jan 16 12:19:17 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to poplar's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   API reference </autoapi/poplar/index>


.. toctree::
   :maxdepth: 1
   :caption: Examples:

   end_to_end_example